pub struct StageCandidate {
pub name: String,
pub overhead_tokens: u32,
pub savings_tokens: u32,
pub applicable: bool,
}Expand description
A stage candidate with its estimated cost and benefit.
Fields
name: StringStage name.
overhead_tokens: u32Estimated overhead in tokens (headers, legends, markers).
savings_tokens: u32Estimated savings in tokens.
applicable: boolWhether this stage is applicable to the content type.
Implementations
Sourceimpl StageCandidate
impl StageCandidate
Sourcepub fn net_benefit(&self) -> i32
pub fn net_benefit(&self) -> i32
Net benefit: savings minus overhead. Negative means the stage hurts.